@@ -1,7 +1,7 @@
 /* -*-c-*- -------------- mixgtk.c :
  * Main functions of the mix gtk front-end
  * ------------------------------------------------------------------
- * $Id: mixgtk.c,v 1.14 2002/03/29 16:31:46 jao Exp $
+ * $Id: mixgtk.c,v 1.15 2002/04/10 23:39:40 jao Exp $
  * ------------------------------------------------------------------
  * Copyright (C) 2001, 2002 Free Software Foundation, Inc.
  *  
@@ -46,7 +46,7 @@ mixgtk_restart (void)
   
   if (!mixgtk_widget_factory_init ())
     {
-      g_error ("Unable to initialise application: missing glade file");
+      g_error (_("Unable to initialise application: missing glade file"));
       return FALSE;
     }
 
@@ -54,7 +54,7 @@ mixgtk_restart (void)
 
   if (!mixgtk_cmd_dispatcher_init (MIXGTK_MAIN))
     {
-      g_error ("Unable to initialise application (command dispatcher)\n");
+      g_error (_("Unable to initialise application (command dispatcher)\n"));
       return FALSE;
     }
 
@@ -62,13 +62,13 @@ mixgtk_restart (void)
   
   if (!mixgtk_mixvm_init (vm, MIXGTK_MIXVM_DIALOG))
     {
-      g_error ("Unable to initialise application (mixvm widgets)\n");
+      g_error (_("Unable to initialise application (mixvm widgets)\n"));
       return FALSE;
     }
 
   if (!mixgtk_mixal_init (vm, MIXGTK_MIXAL_DIALOG))
     {
-      g_error ("Unable to initialise application (mixal widgets)\n");
+      g_error (_("Unable to initialise application (mixal widgets)\n"));
       return FALSE;
     }
 
@@ -77,13 +77,13 @@ mixgtk_restart (void)
 			    (MIXGTK_DEVICES_DIALOG, MIXGTK_WIDGET_DEVICE)),
 			   vm))
     {
-      g_error ("Unable to initialise application (devices)\n");
+      g_error (_("Unable to initialise application (devices)\n"));
       return FALSE;
     }
   
   if (!mixgtk_wm_init ())
     {
-      g_error ("Unable to initialise application (visibility)\n");
+      g_error (_("Unable to initialise application (visibility)\n"));
       return FALSE;
     }
 
