@@ -1,7 +1,7 @@
 /* -*-c-*- ---------------- mixgtk_device.c :
  * actual types for mixgtk devices
  * ------------------------------------------------------------------
- * $Id: mixgtk_device.c,v 1.17 2002/03/29 16:30:49 jao Exp $
+ * $Id: mixgtk_device.c,v 1.19 2002/04/10 23:39:40 jao Exp $
  * ------------------------------------------------------------------
  * Copyright (C) 2001, 2002 Free Software Foundation, Inc.
  *  
@@ -109,7 +109,7 @@ get_word_string_ (mix_word_t w, gboolean dec)
   enum {BUFF_SIZE = 17};
   static gchar BUFFER[BUFF_SIZE] = { 0 };
   if (dec)
-    snprintf (BUFFER, BUFF_SIZE, "%s%011ld",
+    g_snprintf (BUFFER, BUFF_SIZE, "%s%011ld",
 	      mix_word_is_negative (w)? "-" : "+",
 	      mix_word_magnitude (w));
   else
@@ -500,7 +500,7 @@ on_devapp_button_clicked ()
   for (k = 0; k <= LAST_BIN_DEV_; ++k)
     mixgtk_device_set_format (k, IS_DEC (new_decs_, k));
   decs_ = new_decs_;
-  snprintf (value, 20, "%d", decs_);
+  g_snprintf (value, 20, "%d", decs_);
   mixgtk_config_update (DEV_FORMAT_KEY_, value);
 }
 
@@ -551,7 +551,7 @@ devdir_callback (const gchar *file)
 void
 on_devdir_browse_clicked ()
 {
-  mixgtk_get_file (devdir_callback, "Devices dir", mix_device_get_dir ());
+  mixgtk_get_file (devdir_callback, _("Devices dir"), mix_device_get_dir ());
 }
 
 void
