@@ -28,9 +28,9 @@
 #include <glib.h>
 #include "mixgtk_widgets.h"
 
-/* initialise the font selection dialog */
-extern gboolean
-mixgtk_fontsel_init (void);
+/* load default (configured) fonts */
+extern void
+mixgtk_fontsel_load_defaults (void);
 
 /* set a widget's font */
 extern void
