@@ -1,9 +1,9 @@
 /* -*-c-*- -------------- mixgtk_gen_handlers.c :
  * Implementation of the functions declared in mixgtk_gen_handlers.h
  * ------------------------------------------------------------------
- *  Last change: Time-stamp: "2001-04-29 12:32:47 jao"
+ * $Id: mixgtk_gen_handlers.c,v 1.8 2002/04/10 23:39:40 jao Exp $
  * ------------------------------------------------------------------
- * Copyright (C) 2001 Free Software Foundation, Inc.
+ * Copyright (C) 2001, 2002 Free Software Foundation, Inc.
  *  
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -100,7 +100,7 @@ static void open_cb_ (const gchar *file)
 void
 on_file_open_activate (GtkWidget *w, gpointer data)
 {
-  mixgtk_get_file (open_cb_, "Load MIX program...", "*.mix");
+  mixgtk_get_file (open_cb_, _("Load MIX program..."), "*.mix");
 }
 
 /* edit mixal source */
@@ -112,7 +112,7 @@ static void edit_cb_ (const gchar *file)
 void
 on_file_edit_activate (GtkWidget *w, gpointer data)
 {
-  mixgtk_get_file (edit_cb_, "Edit MIXAL source file...",
+  mixgtk_get_file (edit_cb_, _("Edit MIXAL source file..."),
 		   mixgtk_cmd_dispatcher_get_src_path ());
 }
 
@@ -125,7 +125,7 @@ static void compile_cb_ (const gchar *file)
 void
 on_file_compile_activate (GtkWidget *w, gpointer data)
 {
-  mixgtk_get_file (compile_cb_, "Compile MIXAL source file...",
+  mixgtk_get_file (compile_cb_, _("Compile MIXAL source file..."),
 		   mixgtk_cmd_dispatcher_get_src_path ());
 }
 
