@@ -1,9 +1,9 @@
 /* -*-c-*- -------------- mixgtk_input.c :
  * Implementation of the functions declared in mixgtk_input.h
  * ------------------------------------------------------------------
- *  Last change: Time-stamp: "01/04/01 15:24:36 jose"
+ * $Id: mixgtk_input.c,v 1.5 2002/04/09 23:28:19 jao Exp $
  * ------------------------------------------------------------------
- * Copyright (C) 2001 Free Software Foundation, Inc.
+ * Copyright (C) 2001, 2002 Free Software Foundation, Inc.
  *  
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -72,13 +72,13 @@ set_word_ (mix_word_t word)
   gint k;
   gint val = mix_word_magnitude (word);
   gboolean neg = mix_word_is_negative (word);
-  snprintf (BUFFER, SIZE, "%s%d", neg ? "-" : "", val);
+  g_snprintf (BUFFER, SIZE, "%s%d", neg ? "-" : "", val);
   gtk_entry_set_text (GTK_ENTRY (childs_[DEC_]), BUFFER);
   gtk_entry_set_text (GTK_ENTRY (childs_[SIGN_]), neg ? "-" : "+");
   for (k = 1; k < 6; ++k)
     {
       mix_byte_t b = mix_word_get_byte (word, k);
-      snprintf (BUFFER, SIZE, "%d", (int)b);
+      g_snprintf (BUFFER, SIZE, "%d", (int)b);
       gtk_entry_set_text (GTK_ENTRY (childs_[SIGN_ + k]), BUFFER);
     }
 }
