@@ -1,9 +1,9 @@
 /* -*-c-*- -------------- mixgtk_mixal.c :
  * Implementation of the functions declared in mixgtk_mixal.h
  * ------------------------------------------------------------------
- *  Last change: Time-stamp: "2001-04-29 22:30:43 jao"
+ * $Id: mixgtk_mixal.c,v 1.16 2002/04/10 23:39:40 jao Exp $
  * ------------------------------------------------------------------
- * Copyright (C) 2001 Free Software Foundation, Inc.
+ * Copyright (C) 2001, 2002 Free Software Foundation, Inc.
  *  
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -64,7 +64,7 @@ insert_symbol_ (gpointer symbol, gpointer value, gpointer list)
   
   gchar *text[] = {(gchar *)symbol, DEC, WORD};
   mix_word_t w = (mix_word_t)GPOINTER_TO_INT (value);
-  snprintf (DEC, DEC_SIZE, "%s%ld",
+  g_snprintf (DEC, DEC_SIZE, "%s%ld",
 	    mix_word_is_negative (w)? "-" : "+",
 	    mix_word_magnitude (w));
   mix_word_print_to_buffer (w, WORD);
@@ -103,7 +103,7 @@ parse_color_ (const gchar *str)
   static GdkColor color;
   if (sscanf (str, "%hd%hd%hd", &(color.red), &(color.green), &(color.blue)) < 3)
     {
-      g_warning ("Wrong color spec: %s\n", str);
+      g_warning (_("Wrong color spec: %s\n"), str);
       return NULL;
     }
   
@@ -223,7 +223,7 @@ update_tips_ (const mix_symbol_table_t *table,
 	  if (mix_symbol_table_is_defined (table, tokens[k]))
 	    {
 	      mix_word_t val = mix_symbol_table_value (table, tokens[k]);
-	      snprintf (BUFFER, SIZE, "[ %s = %s%ld ]", tokens[k],
+	      g_snprintf (BUFFER, SIZE, "[ %s = %s%ld ]", tokens[k],
 			mix_word_is_negative (val)? "-" : "+",
 			mix_word_magnitude (val));
 	      new_tip = g_strconcat (tip, " ", BUFFER, NULL);
@@ -267,11 +267,12 @@ mixgtk_mixal_load_file (void)
 	{
 	  const gchar *line = mix_src_file_get_line (file, k + 1);
 	  
-	  snprintf (CONT, CONT_SIZE, "%03d:     %s", k + 1, line);
+	  g_snprintf (CONT, CONT_SIZE, "%03d:     %s", k + 1, line);
 	  addr = mix_vm_get_lineno_address (vm_, k + 1);
 	  if (addr != MIX_VM_CELL_NO)
 	    {
-	      sprintf (ADDR, "%04d:   ", mix_short_magnitude (addr));
+	      g_snprintf (ADDR, ADDR_SIZE, "%04d:   ",
+			  mix_short_magnitude (addr));
 	      mix_word_print_to_buffer (mix_vm_get_addr_contents (vm_, addr),
 					ADDR + strlen (ADDR));
 	    }
