@@ -1,9 +1,9 @@
 /* -*-c-*- -------------- mixgtk_wm.c :
  * Implementation of the functions declared in mixgtk_wm.h
  * ------------------------------------------------------------------
- *  Last change: Time-stamp: "2001-06-24 14:36:18 jao"
+ * $Id: mixgtk_wm.c,v 1.6 2002/03/29 16:30:49 jao Exp $
  * ------------------------------------------------------------------
- * Copyright (C) 2001 Free Software Foundation, Inc.
+ * Copyright (C) 2001, 2002 Free Software Foundation, Inc.
  *  
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +21,8 @@
  *  
  */
 
+#include <string.h>
+
 #include "mixgtk_widgets.h"
 #include "mixgtk_config.h"
 #include "mixgtk_wm.h"
