@@ -1,9 +1,9 @@
 /* -*-c-*- -------------- mix_config.c :
  * Implementation of the functions declared in mix_config.h
  * ------------------------------------------------------------------
- *  $Id: mix_config.c,v 1.7 2001/09/18 22:49:56 jao Exp $
+ *  $Id: mix_config.c,v 1.8 2002/04/10 23:39:40 jao Exp $
  * ------------------------------------------------------------------
- * Copyright (C) 2001 Free Software Foundation, Inc.
+ * Copyright (C) 2001, 2002 Free Software Foundation, Inc.
  *  
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -215,7 +215,7 @@ mix_config_save (const mix_config_t *config)
   f = fopen (config->filename, "w");
   if (!f)
     {
-      g_warning ("Unable to open config file %s (%s)",
+      g_warning (_("Unable to open config file %s (%s)"),
 		 config->filename, g_strerror (errno));
       return;
     }
