@@ -2,22 +2,22 @@
  * Declarations for mix_parser_t, which compiles a source file into
  * a mix code file.
  * ------------------------------------------------------------------
- * Copyright (C) 2000 Free Software Foundation, Inc.
- *  
+ * Copyright (C) 2000, 2003 Free Software Foundation, Inc.
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- *  
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *  
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- *  
+ *
  */
 
 
@@ -46,7 +46,7 @@ mix_parser_src_file_extension(const mix_parser_t *parser);
 
 /* Compile a mix source file */
 /* compilation errors */
-typedef enum { 
+typedef enum {
   MIX_PERR_OK,		/* no error */
   MIX_PERR_NOCOMP,	/* file not yet compiled */
   MIX_PERR_INTERNAL,	/* internal error */
@@ -70,7 +70,8 @@ typedef enum {
   MIX_PERR_SYM_INS,	/* symbol has the same name as instruction */
   MIX_PERR_NOWRITE,	/* failed code write */
   MIX_PERR_SHORT_ALF,	/* short ALF operand */
-  MIX_PERR_LONG_ALF	/* too long ALF operand */
+  MIX_PERR_LONG_ALF,	/* too long ALF operand */
+  MIX_PERR_UNQUOTED_ALF /* unquoted ALF operand */
 } mix_parser_err_t;
 
 extern const gchar *
@@ -79,10 +80,10 @@ mix_parser_err_string(mix_parser_err_t error);
 extern mix_parser_err_t
 mix_parser_compile(mix_parser_t *parser);
 
-extern guint 
+extern guint
 mix_parser_warning_count(const mix_parser_t *parser);
 
-extern guint 
+extern guint
 mix_parser_err_count(const mix_parser_t *parser);
 
 /* Write the compilation result to a code file with the given name.
