@@ -1,9 +1,9 @@
 /* -*-c-*- -------------- mix_predicate.c :
  * Implementation of the functions declared in mix_predicate.h
  * ------------------------------------------------------------------
- *  $Id: mix_predicate.c,v 1.3 2001/09/16 22:28:41 jao Exp $
+ * $Id: mix_predicate.c,v 1.5 2002/04/10 23:39:40 jao Exp $
  * ------------------------------------------------------------------
- * Copyright (C) 2001 Free Software Foundation, Inc.
+ * Copyright (C) 2001, 2002 Free Software Foundation, Inc.
  *  
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -173,36 +173,36 @@ mix_predicate_get_message (const mix_predicate_t *predicate)
   switch (predicate->type)
     {
     case MIX_PRED_REG_A:
-      snprintf (BUFFER, SIZE, "Register A changed to %s%ld",
+      g_snprintf (BUFFER, SIZE, _("Register A changed to %s%ld"),
 		mix_word_is_negative (predicate->data.regA)? "-" : "+",
 		mix_word_magnitude (predicate->data.regA));
       break;
     case MIX_PRED_REG_X:
-      snprintf (BUFFER, SIZE, "Register X changed to %s%ld",
+      g_snprintf (BUFFER, SIZE, _("Register X changed to %s%ld"),
 		mix_word_is_negative (predicate->data.regX)? "-" : "+",
 		mix_word_magnitude (predicate->data.regX));
       break;
     case MIX_PRED_REG_J:
-      snprintf (BUFFER, SIZE, "Register J changed to %d",
+      g_snprintf (BUFFER, SIZE, _("Register J changed to %d"),
 		mix_short_magnitude (predicate->data.regI));
       break;
     case MIX_PRED_REG_I1: case MIX_PRED_REG_I2: case MIX_PRED_REG_I3:
     case MIX_PRED_REG_I4: case MIX_PRED_REG_I5: case MIX_PRED_REG_I6: 
-      snprintf (BUFFER, SIZE, "Register I%d changed to %s%d",
+      g_snprintf (BUFFER, SIZE, _("Register I%d changed to %s%d"),
 		predicate->control,
 		mix_short_is_negative (predicate->data.regI)? "-" : "+",
 		mix_short_magnitude (predicate->data.regI));
       break;
     case MIX_PRED_CMP:
-      snprintf (BUFFER, SIZE, "Comparison flag changed to %s",
+      g_snprintf (BUFFER, SIZE, _("Comparison flag changed to %s"),
 		CMP_STRINGS[predicate->data.cmp]);
       break;
     case MIX_PRED_OVER:
-      snprintf (BUFFER, SIZE, "Overflow toggled %s",
+      g_snprintf (BUFFER, SIZE, _("Overflow toggled %s"),
 		predicate->data.over ? "ON" : "OFF");
       break;
     case MIX_PRED_MEM:
-      snprintf (BUFFER, SIZE, "Memory address %d changed to %s%ld",
+      g_snprintf (BUFFER, SIZE, _("Memory address %d changed to %s%ld"),
 		predicate->control,
 		mix_word_is_negative (predicate->data.mem)? "-" : "+",
 		mix_word_magnitude (predicate->data.mem));
