@@ -1,9 +1,9 @@
 /* -*-c-*- -------------- mix_vm_clock.c :
  * Implementation of the functions declared in mix_vm_clock.h
  * ------------------------------------------------------------------
- *  Last change: Time-stamp: "01/02/20 00:23:58 jose"
+ *  $Id: mix_vm_clock.c,v 1.2 2001/09/11 22:53:20 jao Exp $
  * ------------------------------------------------------------------
- * Copyright (C) 2000 Free Software Foundation, Inc.
+ * Copyright (C) 2000, 2001 Free Software Foundation, Inc.
  *  
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -60,7 +60,9 @@ mix_vm_clock_add_lapse (mix_vm_clock_t *clock, const mix_ins_t *ins)
   if (ins != NULL)
     {
       t = exec_times_[ins->opcode];
-      if (ins->opcode == mix_MOVE) t += 2 * (ins->fspec);
+      if (ins->opcode == mix_opMOVE) {
+	t += 2 * (ins->fspec);
+      }
     }
   clock->time += t;
   return t;
