@@ -1,7 +1,7 @@
 /* -*-c-*- -------------- mixvm_command.c :
  * Implementation of the functions declared in mixvm_command.h
  * ------------------------------------------------------------------
- * $Id: mixvm_command.c,v 1.8 2002/04/08 00:32:32 jao Exp $
+ * $Id: mixvm_command.c,v 1.9 2002/04/10 23:39:40 jao Exp $
  * ------------------------------------------------------------------
  * Copyright (C) 2000, 2001, 2002 Free Software Foundation, Inc.
  *  
@@ -163,7 +163,7 @@ emacs_output_ (mix_vm_cmd_dispatcher_t *dis, const gchar *arg, gpointer data)
 static int
 cmd_quit_ (mix_vm_cmd_dispatcher_t *dis, const char *arg)
 {
-  puts ("Quitting ...");
+  puts (_("Quitting ..."));
   if (dis_) mix_vm_cmd_dispatcher_delete (dis_);
   if (config_) mix_config_delete (config_);
   exit (0);
