@@ -1,9 +1,9 @@
 /* -*-c-*- -------------- mixvm_loop.c :
  * Implementation of mix vm command loop.
  * ------------------------------------------------------------------
- *  $Id: mixvm_loop.c,v 1.7 2001/09/24 23:27:02 jao Exp $
+ *  $Id: mixvm_loop.c,v 1.10 2002/04/08 01:59:38 jao Exp $
  * ------------------------------------------------------------------
- * Copyright (C) 2000, 2001 Free Software Foundation, Inc.
+ * Copyright (C) 2000, 2001, 2002 Free Software Foundation, Inc.
  *  
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 
 
 #include <stdio.h>
+#include <string.h>
 
 #include <mixlib/mix.h>
 #include <mixlib/mix_config.h>
@@ -35,6 +36,7 @@
 #endif
 
 #include "mixvm_command.h"
+#include "mixvm_loop.h"
 
 #ifdef HAVE_LIBHISTORY
 #  include <readline/history.h>
@@ -58,8 +60,9 @@ readline (char *prompt)
 /* A static variable for holding the line. */
 static char *line_read = (char *)NULL;
 
-static const char *PROMPT = N_("MIX > ");
+static char *PROMPT = NULL;
 static const char *CONFIG_FILE_ = "mixvm.config";
+static const char *PROMPT_KEY_ = "Prompt";
 
 /* Read a string, and return a pointer to it.  Returns NULL on EOF. */
 static char *
@@ -92,6 +95,7 @@ init_mixvm_ (const gchar *file, gboolean use_emacs)
 {
   static const gchar *HISTORY_FILE = "mixvm.history";
   static gint HISTORY_SIZE = 100;
+  const char *prompt = NULL;
   config_ = mix_config_new (NULL, CONFIG_FILE_);
 
   mix_config_set_autosave (config_, TRUE);
@@ -100,9 +104,25 @@ init_mixvm_ (const gchar *file, gboolean use_emacs)
   if (mix_config_get_history_size (config_) == 0)
     mix_config_set_history_size (config_, HISTORY_SIZE);
   
+  prompt = mix_config_get (config_, PROMPT_KEY_);
+  if (!prompt) prompt = "MIX > ";
+  mix_vmloop_set_prompt (prompt);
+  
   return mixvm_cmd_init (config_, (char *)file, use_emacs);
 }
 
+void
+mix_vmloop_set_prompt (const gchar *prompt) 
+{
+  if (prompt)
+    {
+      if (PROMPT) g_free (PROMPT);
+      if (prompt[0] == '"') prompt++;
+      PROMPT = g_strdup (prompt);
+      if (PROMPT[strlen (PROMPT) - 1] == '"') PROMPT[strlen (PROMPT) - 1] = 0;
+      mix_config_update (config_, PROMPT_KEY_, PROMPT);
+    }
+}
 
 static void
 loop_ (int argc, char *argv[])
@@ -127,12 +147,18 @@ mix_vmloop (int argc, char *argv[], gboolean initfile,
 
 /* run a program and exit */
 void
-mix_vmrun (const gchar *code_file, gboolean dump) 
+mix_vmrun (const gchar *code_file, gboolean dump, gboolean ptime) 
 {
+  gchar *time_cmd = ptime? g_strdup("stime on") : g_strdup("stime off");
+  gchar *run_cmd = g_strdup("run");
+  gchar *dump_cmd = dump? g_strdup("pall") : NULL;
   gboolean result;
   
   init_mixvm_ (code_file, FALSE);
-  result = mixvm_cmd_exec (g_strdup ("run"));
-  if (result && dump) mixvm_cmd_exec (g_strdup ("pall"));
+  result = mixvm_cmd_exec (time_cmd) && mixvm_cmd_exec (run_cmd);
+  if (result && dump) mixvm_cmd_exec (dump_cmd);
   mix_config_delete (config_);
+  g_free(time_cmd);
+  g_free(run_cmd);
+  if (dump_cmd) g_free(dump_cmd);
 }
